"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.OpenLayersGeoJSONView = exports.OpenLayersGeoJSONModel = void 0;
const base_1 = require("@jupyter-widgets/base");
require("ol/ol.css");
const version_1 = require("./version");
require("../css/widget.css");
const GeoJSON_js_1 = __importDefault(require("ol/format/GeoJSON.js"));
const style_js_1 = require("ol/style.js");
const source_js_1 = require("ol/source.js");
const layer_js_1 = require("ol/layer.js");
const layer_1 = require("./layer");
class OpenLayersGeoJSONModel extends layer_1.LayerModel {
    defaults() {
        return Object.assign(Object.assign({}, super.defaults()), { _model_name: OpenLayersGeoJSONModel.model_name, _model_module: OpenLayersGeoJSONModel.model_module, _model_module_version: OpenLayersGeoJSONModel.model_module_version, _view_name: OpenLayersGeoJSONModel.view_name, _view_module: OpenLayersGeoJSONModel.view_module, _view_module_version: OpenLayersGeoJSONModel.view_module_version, layers: [] });
    }
}
exports.OpenLayersGeoJSONModel = OpenLayersGeoJSONModel;
OpenLayersGeoJSONModel.serializers = Object.assign({}, base_1.DOMWidgetModel.serializers);
OpenLayersGeoJSONModel.model_name = 'OpenLayersGeoJSONModel';
OpenLayersGeoJSONModel.model_module = version_1.MODULE_NAME;
OpenLayersGeoJSONModel.model_module_version = version_1.MODULE_VERSION;
OpenLayersGeoJSONModel.view_name = 'OpenLayersGeoJSONView';
OpenLayersGeoJSONModel.view_module = version_1.MODULE_NAME;
OpenLayersGeoJSONModel.view_module_version = version_1.MODULE_VERSION;
class OpenLayersGeoJSONView extends layer_1.LayerView {
    constructor() {
        super(...arguments);
        this.invisibleStyle = new style_js_1.Style({
            fill: new style_js_1.Fill({ color: 'rgba(0, 0, 0, 0)' }),
            stroke: new style_js_1.Stroke({ color: 'rgba(0, 0, 0, 0)', width: 0 }),
        });
    }
    render() {
        this.initVectorLayer();
        this.create_obj();
        this.modelEvents();
    }
    create_obj() {
        this.obj = this.vectorLayer;
    }
    initVectorLayer() {
        this.vectorSource = new source_js_1.Vector({
            features: new GeoJSON_js_1.default().readFeatures(this.model.get('data')),
        });
        this.vectorLayer = new layer_js_1.Vector({
            source: this.vectorSource,
            style: this.createStyleFunction(),
        });
    }
    createStyleFunction() {
        const modelStyle = this.model.get('style') || {};
        return (feature) => {
            return new style_js_1.Style({
                stroke: new style_js_1.Stroke({
                    color: modelStyle.strokeColor || '#3399CC',
                    width: modelStyle.strokeWidth || 1.25,
                }),
                fill: new style_js_1.Fill({
                    color: modelStyle.fillColor || 'rgba(255, 255, 255, 0.4)',
                }),
                image: new style_js_1.Circle({
                    radius: modelStyle.pointRadius || 5,
                    fill: new style_js_1.Fill({
                        color: modelStyle.pointFillColor || '#FF0000',
                    }),
                    stroke: new style_js_1.Stroke({
                        color: modelStyle.pointStrokeColor || '#000000',
                        width: modelStyle.pointStrokeWidth || 1,
                    }),
                }),
            });
        };
    }
    updateStyle() {
        this.vectorLayer.setStyle(this.createStyleFunction());
    }
    updateVisibility() {
        const visibility = this.model.get('visible');
        this.vectorSource.getFeatures().forEach((feature) => {
            feature.setStyle(visibility ? undefined : this.invisibleStyle);
        });
    }
    updateData() {
        this.vectorSource.clear();
        this.vectorSource.addFeatures(new GeoJSON_js_1.default().readFeatures(this.model.get('data')));
    }
    modelEvents() {
        this.listenTo(this.model, 'change:style', this.updateStyle);
        this.listenTo(this.model, 'change:data', this.updateData);
        this.listenTo(this.model, 'change:visible', this.updateVisibility);
    }
}
exports.OpenLayersGeoJSONView = OpenLayersGeoJSONView;
//# sourceMappingURL=geojson.js.map