"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HeatmapLayerView = exports.HeatmapLayerModel = void 0;
const layer_1 = require("./layer");
const version_1 = require("./version");
const Heatmap_1 = __importDefault(require("ol/layer/Heatmap"));
const source_1 = require("ol/source");
const Feature_1 = __importDefault(require("ol/Feature"));
const Point_1 = __importDefault(require("ol/geom/Point"));
class HeatmapLayerModel extends layer_1.LayerModel {
    defaults() {
        return Object.assign(Object.assign({}, super.defaults()), { _model_name: HeatmapLayerModel.model_name, _model_module: HeatmapLayerModel.model_module, _model_module_version: HeatmapLayerModel.model_module_version, _view_name: HeatmapLayerModel.view_name, _view_module: HeatmapLayerModel.view_module, _view_module_version: HeatmapLayerModel.view_module_version, blur: 15, radius: 8, points: [] });
    }
}
exports.HeatmapLayerModel = HeatmapLayerModel;
HeatmapLayerModel.serializers = Object.assign({}, layer_1.LayerModel.serializers);
HeatmapLayerModel.model_name = 'HeatmapLayerModel';
HeatmapLayerModel.model_module = version_1.MODULE_NAME;
HeatmapLayerModel.model_module_version = version_1.MODULE_VERSION;
HeatmapLayerModel.view_name = 'HeatmapLayerView';
HeatmapLayerModel.view_module = version_1.MODULE_NAME;
HeatmapLayerModel.view_module_version = version_1.MODULE_VERSION;
class HeatmapLayerView extends layer_1.LayerView {
    render() {
        this.create_obj();
        this.modelEvents();
    }
    create_obj() {
        const source = new source_1.Vector({
            features: this.model
                .get('points')
                .map((point) => {
                const feature = new Feature_1.default(new Point_1.default([point[1], point[0]])); // Note: [lon, lat]
                feature.set('weight', point[2]);
                return feature;
            }),
        });
        this.obj = new Heatmap_1.default({
            source: source,
            blur: this.model.get('blur'),
            radius: this.model.get('radius'),
        });
    }
    modelEvents() {
        this.model.on('change:blur', this.update_blur, this);
        this.model.on('change:radius', this.update_radius, this);
        this.model.on('change:points', this.update_points, this);
    }
    update_blur() {
        this.obj.setBlur(this.model.get('blur'));
    }
    update_radius() {
        this.obj.setRadius(this.model.get('radius'));
    }
    update_points() {
        const source = new source_1.Vector({
            features: this.model
                .get('points')
                .map((point) => {
                const feature = new Feature_1.default(new Point_1.default([point[1], point[0]])); // Note: [lon, lat]
                feature.set('weight', point[2]);
                return feature;
            }),
        });
        this.obj.setSource(source);
    }
}
exports.HeatmapLayerView = HeatmapLayerView;
//# sourceMappingURL=heatmap.js.map