"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.VectorTileLayerView = exports.VectorTileLayerModel = void 0;
// Copyright (c) QuantStack
// Distributed under the terms of the Modified BSD License.
const base_1 = require("@jupyter-widgets/base");
const VectorTile_1 = __importDefault(require("ol/layer/VectorTile"));
const VectorTile_2 = __importDefault(require("ol/source/VectorTile"));
const version_1 = require("./version");
const layer_1 = require("./layer");
const tilegrid_1 = require("ol/tilegrid");
const MVT_1 = __importDefault(require("ol/format/MVT"));
const GeoJSON_1 = __importDefault(require("ol/format/GeoJSON"));
const TopoJSON_1 = __importDefault(require("ol/format/TopoJSON"));
const style_js_1 = require("ol/style.js");
class VectorTileLayerModel extends layer_1.LayerModel {
    defaults() {
        return Object.assign(Object.assign({}, super.defaults()), { _model_name: VectorTileLayerModel.model_name, _model_module: VectorTileLayerModel.model_module, _model_module_version: VectorTileLayerModel.model_module_version, _view_name: VectorTileLayerModel.view_name, _view_module: VectorTileLayerModel.view_module, _view_module_version: VectorTileLayerModel.view_module_version, features: [] });
    }
}
exports.VectorTileLayerModel = VectorTileLayerModel;
VectorTileLayerModel.serializers = Object.assign({}, base_1.DOMWidgetModel.serializers);
VectorTileLayerModel.model_name = 'VectorTileLayerModel';
VectorTileLayerModel.model_module = version_1.MODULE_NAME;
VectorTileLayerModel.model_module_version = version_1.MODULE_VERSION;
VectorTileLayerModel.view_name = 'VectorTileLayerView';
VectorTileLayerModel.view_module = version_1.MODULE_NAME;
VectorTileLayerModel.view_module_version = version_1.MODULE_VERSION;
class VectorTileLayerView extends layer_1.LayerView {
    render() {
        super.render();
        this.model.on('change:url', this.urlChanged, this);
        this.model.on('change:style', this.styleChanged, this);
        this.model.on('change:visible', this.visibilityChanged, this);
        this.model.on('change:opacity', this.opacityChanged, this);
        this.model.on('change:attribution', this.attributionChanged, this);
        this.model.on('change:max_zoom', this.maxZoomChanged, this);
        this.model.on('change:min_zoom', this.minZoomChanged, this);
    }
    create_obj() {
        this.urlChanged();
        this.styleChanged();
        this.visibilityChanged();
        this.opacityChanged();
        this.attributionChanged();
        this.maxZoomChanged();
        this.minZoomChanged();
    }
    urlChanged() {
        const newUrl = this.model.get('url');
        if (newUrl) {
            const sourceFormat = this.model.get('source_format') || { type: 'MVT' };
            let format;
            switch (sourceFormat.type) {
                case 'MVT':
                    format = new MVT_1.default({
                        layerName: sourceFormat.layer_name,
                        layers: sourceFormat.layers,
                    });
                    break;
                case 'GeoJSON':
                    format = new GeoJSON_1.default({
                        dataProjection: sourceFormat.dataProjection || 'EPSG:4326',
                        featureProjection: sourceFormat.featureProjection,
                        geometryName: sourceFormat.geometry_name,
                        extractGeometryName: sourceFormat.extractGeometryName || false,
                    });
                    break;
                case 'TopoJSON':
                    format = new TopoJSON_1.default({
                        dataProjection: sourceFormat.dataProjection || 'EPSG:4326',
                        layerName: sourceFormat.layer_name,
                        layers: sourceFormat.layers,
                    });
                    break;
                default:
                    format = new MVT_1.default({
                        layerName: sourceFormat.layer_name,
                        layers: sourceFormat.layers,
                    });
                    break;
            }
            const vectorTileSource = new VectorTile_2.default({
                format: format,
                url: newUrl,
                tileGrid: (0, tilegrid_1.createXYZ)({ maxZoom: 19 }),
                attributions: this.model.get('attribution'),
                maxZoom: this.model.get('max_zoom'),
                minZoom: this.model.get('min_zoom'),
            });
            if (this.obj) {
                this.obj.setSource(vectorTileSource);
            }
            else {
                this.obj = new VectorTile_1.default({
                    source: vectorTileSource,
                    visible: this.model.get('visible'),
                    opacity: this.model.get('opacity'),
                    style: this.createStyleFunction(),
                });
            }
        }
    }
    visibilityChanged() {
        const visible = this.model.get('visible');
        if (this.obj) {
            this.obj.setVisible(visible);
        }
    }
    opacityChanged() {
        const opacity = this.model.get('opacity');
        if (this.obj) {
            this.obj.setOpacity(opacity);
        }
    }
    attributionChanged() {
        const attribution = this.model.get('attribution');
        if (this.obj) {
            const source = this.obj.getSource();
            if (source) {
                source.setAttributions(attribution);
            }
        }
    }
    maxZoomChanged() {
        const maxZoom = this.model.get('max_zoom');
        if (this.obj) {
            const source = this.obj.getSource();
            if (source) {
                source.set('maxZoom', maxZoom);
            }
        }
    }
    minZoomChanged() {
        const minZoom = this.model.get('min_zoom');
        if (this.obj) {
            const source = this.obj.getSource();
            if (source) {
                source.set('minZoom', minZoom);
            }
        }
    }
    styleChanged() {
        if (this.obj) {
            const styleFunction = this.createStyleFunction();
            this.obj.setStyle(styleFunction);
        }
    }
    createStyleFunction() {
        const modelStyle = this.model.get('style') || {};
        return (feature) => {
            return new style_js_1.Style({
                stroke: new style_js_1.Stroke({
                    color: modelStyle.strokeColor || '#3399CC',
                    width: modelStyle.strokeWidth || 1.25,
                }),
                fill: new style_js_1.Fill({
                    color: modelStyle.fillColor || 'rgba(255, 255, 255, 0.4)',
                }),
                image: new style_js_1.Circle({
                    radius: modelStyle.pointRadius || 5,
                    fill: new style_js_1.Fill({
                        color: modelStyle.pointFillColor || '#0000FF',
                    }),
                    stroke: new style_js_1.Stroke({
                        color: modelStyle.pointStrokeColor || '#000000',
                        width: modelStyle.pointStrokeWidth || 1,
                    }),
                }),
            });
        };
    }
}
exports.VectorTileLayerView = VectorTileLayerView;
//# sourceMappingURL=vectortilelayer.js.map