"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MapView = exports.MapModel = void 0;
// Copyright (c) QuantStack
// Distributed under the terms of the Modified BSD License.
const base_1 = require("@jupyter-widgets/base");
const Tile_1 = __importDefault(require("ol/layer/Tile"));
const ol_1 = require("ol");
const View_1 = __importDefault(require("ol/View"));
require("ol/ol.css");
const version_1 = require("./version");
require("../css/widget.css");
const proj_1 = require("ol/proj");
const source_1 = require("ol/source");
__exportStar(require("./imageoverlay"), exports);
__exportStar(require("./geojson"), exports);
__exportStar(require("./video_overlay"), exports);
__exportStar(require("./popupoverlay"), exports);
__exportStar(require("./zoomslider"), exports);
__exportStar(require("./fullscreen"), exports);
__exportStar(require("./scaleline"), exports);
__exportStar(require("./mouseposition"), exports);
__exportStar(require("./heatmap"), exports);
__exportStar(require("./rastertilelayer"), exports);
__exportStar(require("./geotifflayer"), exports);
__exportStar(require("./vectortilelayer"), exports);
const DEFAULT_LOCATION = [0.0, 0.0];
class MapModel extends base_1.DOMWidgetModel {
    defaults() {
        return Object.assign(Object.assign({}, super.defaults()), { _model_name: MapModel.model_name, _model_module: MapModel.model_module, _model_module_version: MapModel.model_module_version, _view_name: MapModel.view_name, _view_module: MapModel.view_module, _view_module_version: MapModel.view_module_version, layers: [], controls: [], overlays: [], zoom: 2, center: DEFAULT_LOCATION });
    }
}
exports.MapModel = MapModel;
MapModel.serializers = Object.assign(Object.assign({}, base_1.DOMWidgetModel.serializers), { layers: { deserialize: base_1.unpack_models }, overlays: { deserialize: base_1.unpack_models }, controls: { deserialize: base_1.unpack_models } });
MapModel.model_name = 'MapModel';
MapModel.model_module = version_1.MODULE_NAME;
MapModel.model_module_version = version_1.MODULE_VERSION;
MapModel.view_name = 'MapView';
MapModel.view_module = version_1.MODULE_NAME;
MapModel.view_module_version = version_1.MODULE_VERSION;
class MapView extends base_1.DOMWidgetView {
    render() {
        (0, proj_1.useGeographic)();
        this.el.classList.add('jupyter-widgets');
        this.el.classList.add('ipyopenlayer-widgets');
        this.map_container = document.createElement('div');
        this.map_container.classList.add('ol-container');
        requestAnimationFrame(() => {
            const parentElement = this.el.parentElement;
            if (parentElement) {
                parentElement.classList.add('ipyopenlayer-map-container-wrapper');
                const grandParentElement = parentElement.parentElement;
                if (grandParentElement) {
                    grandParentElement.classList.add('ipyopenlayer-map-container-wrapper-parent');
                }
            }
        });
        this.el.appendChild(this.map_container);
        this.layerViews = new base_1.ViewList(this.addLayerModel, this.removeLayerView, this);
        this.overlayViews = new base_1.ViewList(this.addOverlayModel, this.removeOverlayView, this);
        this.controlViews = new base_1.ViewList(this.addControlModel, this.removeControlView, this);
        this.map = new ol_1.Map({
            target: this.map_container,
            view: new View_1.default({
                center: this.model.get('center'),
                zoom: this.model.get('zoom'),
            }),
            layers: [
                new Tile_1.default({
                    source: new source_1.OSM(),
                }),
            ],
        });
        this.map.on('click', (event) => {
            this.handleMapClick(event);
        });
        this.map.getView().on('change:center', () => {
            this.model.set('center', this.map.getView().getCenter());
            this.model.save_changes();
        });
        this.map
            .getView()
            .on('change:resolution', (event) => {
            this.model.set('zoom', this.map.getView().getZoom());
            this.model.save_changes();
        });
        this.layersChanged();
        this.overlayChanged();
        this.controlChanged();
        this.model.on('change:layers', this.layersChanged, this);
        this.model.on('change:overlays', this.overlayChanged, this);
        this.model.on('change:controls', this.controlChanged, this);
        this.model.on('change:zoom', this.zoomChanged, this);
        this.model.on('change:center', this.centerChanged, this);
    }
    handleMapClick(event) {
        const coordinate = event.coordinate;
        const [lon, lat] = coordinate;
        this.send({ type: 'click', lon, lat });
    }
    layersChanged() {
        const layers = this.model.get('layers');
        this.layerViews.update(layers);
    }
    overlayChanged() {
        const overlay = this.model.get('overlays');
        this.overlayViews.update(overlay);
    }
    controlChanged() {
        const control = this.model.get('controls');
        this.controlViews.update(control);
    }
    zoomChanged() {
        const newZoom = this.model.get('zoom');
        if (newZoom !== undefined && newZoom !== null) {
            this.map.getView().setZoom(newZoom);
        }
    }
    centerChanged() {
        const newCenter = this.model.get('center');
        if (newCenter !== undefined && newCenter !== null) {
            this.map.getView().setCenter(newCenter);
        }
    }
    removeLayerView(child_view) {
        this.map.removeLayer(child_view.obj);
        child_view.remove();
    }
    removeOverlayView(child_view) {
        if (child_view.overlay) {
            this.map.removeOverlay(child_view.overlay);
        }
        child_view.remove();
    }
    removeControlView(child_view) {
        this.map.removeControl(child_view.obj);
        child_view.remove();
    }
    addLayerModel(child_model) {
        return __awaiter(this, void 0, void 0, function* () {
            const view = yield this.create_child_view(child_model, {
                map_view: this,
            });
            this.map.addLayer(view.obj);
            this.displayed.then(() => {
                view.trigger('displayed', this);
            });
            return view;
        });
    }
    addOverlayModel(child_model) {
        return __awaiter(this, void 0, void 0, function* () {
            const view = yield this.create_child_view(child_model, {
                map_view: this,
            });
            this.map.addOverlay(view.overlay);
            this.displayed.then(() => {
                view.trigger('displayed', this);
            });
            return view;
        });
    }
    addControlModel(child_model) {
        return __awaiter(this, void 0, void 0, function* () {
            const view = yield this.create_child_view(child_model, {
                map_view: this,
            });
            if (view.obj) {
                this.map.addControl(view.obj);
                this.displayed.then(() => {
                    view.trigger('displayed', this);
                });
            }
            return view;
        });
    }
}
exports.MapView = MapView;
//# sourceMappingURL=widget.js.map